@@ -61,6 +61,31 @@ static bool is_quick_login()
     return true;
 }
 
+static bool is_config_auto_open_whitebox()
+{
+    bool enable = false;
+
+    const char *cmd = "dde-dconfig --get -a org.deepin.dde.keyring -r org.deepin.dde.keyring.whitebox -k autoOpenWhitebox";
+    FILE *fp = popen(cmd, "r");
+    if (fp == NULL) {
+        DK_LOG(LOG_WARNING, "unable to open pipe !");
+        return enable;
+    }
+
+    const char *flag = "true";
+    char buf[strlen(flag) + 1];
+    if (fgets(buf, sizeof(buf), fp) != NULL) {
+        if (strcmp(buf, flag) == 0) {
+            enable = true;
+        }
+    }
+
+    pclose(fp);
+
+    DK_LOG(LOG_INFO, "auto open whitebox: %d", enable);
+    return enable;
+}
+
 static int check_change_password_type(const char *workDir, const char *argValuePWType)
 {
     int type = CHANGE_PASSWORD_NONE;
@@ -79,6 +104,9 @@ static int check_change_password_type(const char *workDir, const char *argValueP
             } else if (is_udcp()) {
                 // 域管用户，如果没有开启白盒，则自动开启白盒
                 type = CHANGE_PASSWORD_TO_WHITEBOX;
+            } else if (is_config_auto_open_whitebox()) {
+                // autoOpenWhitebox配置开启，则自动开启白盒
+                type = CHANGE_PASSWORD_TO_WHITEBOX;
             }
         }
     } else if (strcmp(argValuePWType, argPWTypeForce) == 0) {
@@ -438,4 +466,4 @@ int main(int argc, char *argv[])
     arg_clean(&argh);
     DK_LOG(LOG_INFO, "end.");
     return 0;
-}
\ No newline at end of file
+}
