@@ -54,7 +54,9 @@ QStringList GnomeKeyringExtention::interestedActions() const
         << ActionEnrollIris
         << ActionPasskeyRegister
         << ActionEnableQuickLogin
-        << ActionDisableQuickLogin;
+        << ActionDisableQuickLogin
+        << ActionEnableWechatAuth
+        << ActionDisableWechatAuth;
 
     return ret;
 }
@@ -79,9 +81,10 @@ QButtonGroup *GnomeKeyringExtention::options()
         || actionID == ActionEnrollFace
         || actionID == ActionEnrollIris
         || actionID == ActionPasskeyRegister
-        || actionID == ActionEnableQuickLogin) {
+        || actionID == ActionEnableQuickLogin
+        || actionID == ActionEnableWechatAuth) {
         m_checkBtn.data()->setText("use whitebox keyring"); // 现在不需要交互, 文案随便填的
-    } else if (actionID == ActionDisableAutoLogin || actionID == ActionDisableNopassLogin) {
+    } else if (actionID == ActionDisableAutoLogin || actionID == ActionDisableNopassLogin || actionID == ActionDisableWechatAuth) {
         m_checkBtn.data()->setText("do not use whitebox keyring");
     }
 
@@ -109,17 +112,18 @@ void GnomeKeyringExtention::extendedDo()
     const QString actionID = m_proxy->actionID();
     const QString password = m_proxy->password();
 
-    if (actionID == ActionEnableAutoLogin 
+    if (actionID == ActionEnableAutoLogin
         || actionID == ActionEnableNopassLogin
         || actionID == ActionEnrollFingerprint
         || actionID == ActionEnrollFace
         || actionID == ActionEnrollIris
         || actionID == ActionPasskeyRegister
-        || actionID == ActionEnableQuickLogin) {
+        || actionID == ActionEnableQuickLogin
+        || actionID == ActionEnableWechatAuth) {
         if (!m_checkBtn.isNull() && m_checkBtn.data()->checkState() == Qt::Checked) {
             useWhiteboxPassword(password);
         }
-    } else if (actionID == ActionDisableAutoLogin || actionID == ActionDisableNopassLogin) {
+    } else if (actionID == ActionDisableAutoLogin || actionID == ActionDisableNopassLogin || actionID == ActionDisableWechatAuth) {
         if (!m_checkBtn.isNull() && m_checkBtn.data()->checkState() == Qt::Checked) {
             useUserPassword(password);
         }
